@@ -16,20 +16,20 @@ import logo32 from '../style/logos/sqlite-logo-32x32.png';
 import logo64 from '../style/logos/sqlite-logo-64x64.png';
 
 const server_kernel: JupyterLiteServerPlugin<void> = {
-  id: '@jupyterlite/xeus-kernel-extension:kernel',
+  id: '@jupyterlite/xeus-sqlite-kernel-extension:kernel',
   autoStart: true,
   requires: [IKernelSpecs],
   activate: (app: JupyterLiteServer, kernelspecs: IKernelSpecs) => {
     kernelspecs.register({
       spec: {
-        name: 'Sqlite',
-        display_name: 'Sqlite',
+        name: 'SQLite',
+        display_name: 'SQLite',
         language: 'sql',
         argv: [],
         spec: {
           argv: [],
           env: {},
-          display_name: 'Sqlite',
+          display_name: 'SQLite',
           language: 'sql',
           interrupt_mode: 'message',
           metadata: {}
